@@ -70,6 +70,7 @@ class Insane:
 class SoloInsane:
     def __init__(self, data):
         self.name = "Solo Insane"
+        # self.games_played = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("games_played_solo_insane", 0)
         self.winstreak = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("win_streak_solo_insane", 0)
         self.kills = KillsDeaths(
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("kills_solo_insane", 0),
@@ -80,10 +81,14 @@ class SoloInsane:
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("losses_solo_insane", 0)
         )
 
+    def __str__(self):
+        return self.name
+
 
 class DoublesInsane:
     def __init__(self, data):
         self.name = "Doubles Insane"
+        # self.games_played = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("games_played_doubles_insane", 0)
         self.winstreak = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("win_streak_doubles_insane", 0)
         self.kills = KillsDeaths(
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("kills_doubles_insane", 0),
@@ -93,3 +98,6 @@ class DoublesInsane:
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("wins_doubles_insane", 0),
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("losses_doubles_insane", 0)
         )
+
+    def __str__(self):
+        return self.name
\ No newline at end of file
